get_boot_time_secs

Function get_boot_time_secs 

pub fn get_boot_time_secs() -> i64
Get the system boot time in seconds since UNIX epoch

This uses the platform process backend and caches the result.